import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="testwizard.commands-video",
    version="3.1.3",
    author="Eurofins Digital Testing - Belgium",
    author_email="support-be@eurofins.com",
    description="Testwizard Video commands",
    long_description=long_description,
    long_description_content_type="text/markdown",
    packages=['testwizard.commands_video'],
    install_requires=[
        'testwizard.commands-core==3.1.3'
    ],
    classifiers=[
        "Programming Language :: Python :: 3.3",
        "Development Status :: 5 - Production/Stable",
        "Operating System :: OS Independent",
    ],
)


















